parse_line

Function parse_line 

pub fn parse_line(bytes: &[u8]) -> Option<(RawEventLine<'_>, &[u8])>
Tries to read the next RawEventLine from bytes. Returns None if bytes contains no complete EOL, this includes a slice ending in just cr as we are not yet sure if it’s crlf or just a lone cr.